@@ -10,9 +10,12 @@ sampleN.HVNTID <- function(alpha=0.05, targetpower=0.8, theta0, theta1, theta2,
                            CV, design=c("2x2x4", "2x2x3"), nsims=1E5, nstart, 
                            imax=100, print=TRUE, details=TRUE, setseed=TRUE)
 {
-  if (missing(theta1) & missing(theta2)) theta1 <- 0.8
   if (missing(theta0)) theta0 <- 0.95
-  if (missing(theta2)) theta2=1/theta1
+  
+  if (missing(theta1) & missing(theta2)) theta1 <- 0.8
+  if (missing(theta2)) theta2 <- 1/theta1
+  if (missing(theta1)) theta1 <- 1/theta2
+  
   if ( (theta0<=theta1) | (theta0>=theta2) ) {
     stop("Null ratio ",theta0," not between margins ",theta1," / ",theta2,"!", 
          call.=FALSE)
