@@ -1,9 +1,11 @@
-#---------------------------------------------------------------------------
+#-----------------------------------------------------------------------------
 # Sample size for partial and full replicate design and scaled ABE 
 # via simulated (empirical) power
+# estimation method ANOVA and BE decision via ABEL (Average bioequivalence with 
+# expanding eimits)
 # 
 # Author: dlabes
-#---------------------------------------------------------------------------
+#-----------------------------------------------------------------------------
 
 # helper function: sample size for pe in a range?
 # definition is more or less empirical (i.e. not understood by me)
@@ -17,8 +19,8 @@
 
 sampleN.scABEL <- function(alpha=0.05, targetpower=0.8, theta0, theta1, 
                            theta2, CV, design=c("2x3x3", "2x2x4", "2x2x3"), 
-                           regulator=c("EMA", "ANVISA", "FDA"), nsims=1E5,
-                           nstart, imax=100, print=TRUE, details=TRUE, setseed=TRUE)
+                           regulator, nsims=1E5, nstart, imax=100, print=TRUE, 
+                           details=TRUE, setseed=TRUE)
 {
   if (missing(theta1) & missing(theta2)) theta1 <- 0.8
   if (missing(theta2)) theta2=1/theta1
@@ -40,14 +42,14 @@ sampleN.scABEL <- function(alpha=0.05, targetpower=0.8, theta0, theta1,
   s2wT <- log(1.0 + CVwT^2)
   s2wR <- log(1.0 + CVwR^2)
   
-  # check regulator
-  regulator <- toupper(regulator)
-  regulator <- match.arg(regulator)
-  # constants acc. to regulatory bodies
-  rc       <- reg_const(regulator)
-  CVcap    <- rc$CVcap
-  CVswitch <- rc$CVswitch
-  r_const  <- rc$r_const
+  if(missing(regulator)) regulator <- "EMA"
+  # check regulator and get 
+  # constants acc. to regulatory bodies (function in scABEL.R)
+  rc <- reg_check(regulator)
+  CVcap     <- rc$CVcap
+  CVswitch  <- rc$CVswitch
+  r_const   <- rc$r_const
+  pe_constr <- rc$pe_constr
   
   # check design
   design <- match.arg(design)
@@ -97,17 +99,13 @@ sampleN.scABEL <- function(alpha=0.05, targetpower=0.8, theta0, theta1,
     cat("alpha  = ", alpha,", target power = ", targetpower,"\n", sep="")
     cat("CVw(T) = ", CVwT,"; CVw(R) = ", CVwR,"\n", sep="")
     cat("Null (true) ratio = ",theta0,"\n", sep="")
-    cat("ABE limits / PE constraints =", theta1,"...", theta2,"\n")
-    cat("Regulatory settings:", regulator,"\n")
-    if (details) { 
-      cat("- CVswitch = ", CVswitch)
-      if (is.finite(CVcap)){
-        cat(", cap on scABEL if CVw(R) > ", CVcap,"\n",sep="")
-      } else {
-        cat(", no cap on scABEL\n", sep="")
-      }  
-      cat("- Regulatory constant =", r_const,"\n")
-    }     
+    cat("ABE limits / PE constraint =", theta1,"...", theta2,"\n")
+    if (details | rc$name=="USER") { 
+      print(rc)
+      cat("\n")
+    } else {
+      cat("Regulatory settings:", rc$name,"\n")
+    }
   }
   
   # -----------------------------------------------------------------
@@ -133,9 +131,9 @@ sampleN.scABEL <- function(alpha=0.05, targetpower=0.8, theta0, theta1,
     #if(Emse < CV2mse(0.305) & Emse > CV2mse(0.295) & abs(mlog)>log(1/0.865)) {
     if(Emse < CV2mse(CVswitch+0.005) & Emse > CV2mse(CVswitch-0.005) 
         & abs(mlog)>log(1/0.865)) {
-      if (regulator=="EMA")     n01 <- 0.9*n01
-      if (regulator=="FDA")     n01 <- 0.65*n01
-      if (regulator=="ANVISA")  n01 <- 0.6*n01
+      if (rc$name=="EMA")     n01 <- 0.9*n01
+      if (rc$name=="FDA")     n01 <- 0.65*n01
+      if (rc$name=="ANVISA")  n01 <- 0.6*n01
       n01 <- seqs*trunc(n01/seqs)
     }
     
@@ -158,7 +156,7 @@ sampleN.scABEL <- function(alpha=0.05, targetpower=0.8, theta0, theta1,
 
   if(setseed) set.seed(123456)
   p <- .power.scABEL(mlog, sdm, C2, Emse, cvec, df, s2wR, dfRR, s2wT, dfTT,
-                     design, nsims, CVswitch, r_const, CVcap, 
+                     design, nsims, CVswitch, r_const, CVcap, pe_constr,
                      ln_lBEL=log(theta1),ln_uBEL=log(theta2), alpha=alpha)
   pwr <- as.numeric(p["BE"]);
   pd <- max(4,round(log10(nsims),0)-1)  # digits for power
@@ -190,7 +188,7 @@ sampleN.scABEL <- function(alpha=0.05, targetpower=0.8, theta0, theta1,
     dfTT <- dfRR
     if(setseed) set.seed(123456)
     p <- .power.scABEL(mlog, sdm, C2, Emse, cvec, df, s2wR, dfRR, s2wT, dfTT,
-                       design, nsims, CVswitch, r_const, CVcap, 
+                       design, nsims, CVswitch, r_const, CVcap, pe_constr,
                        ln_lBEL=log(theta1),ln_uBEL=log(theta2), alpha=alpha)
     pwr <- as.numeric(p["BE"]);
     
@@ -210,7 +208,7 @@ sampleN.scABEL <- function(alpha=0.05, targetpower=0.8, theta0, theta1,
     dfTT <- dfRR
     if(setseed) set.seed(123456)
     p <- .power.scABEL(mlog, sdm, C2, Emse, cvec, df, s2wR, dfRR, s2wT, dfTT,
-                       design, nsims, CVswitch, r_const, CVcap, 
+                       design, nsims, CVswitch, r_const, CVcap, pe_constr, 
                        ln_lBEL=log(theta1),ln_uBEL=log(theta2), alpha=alpha)
     pwr <- as.numeric(p["BE"]);
     
